function E  = calculateTotalEnergy(~,psi,Params,Transf,VDk,V)

    % Parameters
    normfac = Params.Lx*Params.Ly*Params.Lz/numel(psi);
    KEop    = 0.5*(Transf.KX.^2+Transf.KY.^2+Transf.KZ.^2);
    
    % DDIs
    frho    = fftn(abs(psi).^2);
    Phi     = real(ifftn(frho.*VDk));
    Eddi    = 0.5*Params.gdd*Phi.*abs(psi).^2;
    
    % Kinetic energy
    Ekin    = KEop.*abs(fftn(psi)*normfac).^2;
    Ekin    = sum(Ekin(:))*Transf.dkx*Transf.dky*Transf.dkz/(2*pi)^3;
    
    % Potential energy
    Epot    = V.*abs(psi).^2;
    
    % Contact interactions
    Eint    = 0.5*Params.gs*abs(psi).^4;
    
    % Quantum fluctuations
    Eqf     = 0.4*Params.gammaQF*abs(psi).^5;
    
    % Total energy
    E       = Ekin + sum(Epot(:) + Eint(:) + Eddi(:) + Eqf(:))*Transf.dx*Transf.dy*Transf.dz;

end